@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemDb.php 909 2008-08-12 07:23:06Z fishbone $
+ * @version    SVN: $Id: systemDb.php 1061 2008-10-07 08:20:28Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -1901,12 +1901,14 @@ class SystemDb extends BaseDb
 		
 		$logSerial = $gEnvManager->getCurrentAccessLogSerial();	// 現在のアクセスログシリアル番号
 		$time = sprintf('%01.06f', microtime(true) - M3_MTIME);
+		$memoryUsage = 0;
+		if (function_exists('memory_get_usage')) $memoryUsage = memory_get_usage();
 		
 		// トランザクション開始
 		$this->startTransaction();
 		
-		$sql = "INSERT INTO _debug (db_method, db_message, db_access_log_serial, db_time, db_dt) VALUES (?, ?, ?, ?, now())";
-		$params = array($method, $message, $logSerial, $time);
+		$sql = "INSERT INTO _debug (db_method, db_message, db_access_log_serial, db_memory_usage, db_time, db_dt) VALUES (?, ?, ?, ?, ?, now())";
+		$params = array($method, $message, $logSerial, $memoryUsage, $time);
 		$this->execStatement($sql, $params);
 
 		// トランザクション終了
