@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 1034 2008-09-22 10:18:17Z fishbone $
+ * @version    SVN: $Id: envManager.php 1064 2008-10-09 07:15:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/core/version.php');	// システムバージョンクラス
@@ -62,6 +62,9 @@ class EnvManager
 	{
 		global $gInstanceManager;
 		
+		// データ初期化
+		$this->workDir = M3_SYSTEM_WORK_DIR_PATH;// 作業用ディレクトリ
+		
 		// システムバージョンオブジェクト作成
 		$this->sysVersion = new m3Version();
 		
@@ -117,7 +120,6 @@ class EnvManager
 		$this->mobileEncoding = $this->db->getSystemConfig(self::MOBILE_ENCODING);	// 携帯用の入力、出力エンコーディング
 		
 		// 作業用ディレクトリ
-		$this->workDir = M3_SYSTEM_WORK_DIR_PATH;
 		$value = $this->db->getSystemConfig(self::CONFIG_ID_WORK_DIR);
 		if (!empty($value)) $this->workDir = $value;
 	}
