@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1026 2008-09-20 07:31:52Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1072 2008-10-11 10:30:30Z fishbone $
  * @link       http://www.magic3.org
  */
 class PageManager
@@ -82,6 +82,7 @@ class PageManager
 	const LIB_JQUERY_CLUETIP	= 'jquery.cluetip';
 	const LIB_JQUERY_UI_PLUS	= 'jquery-ui-plus';
 	const LIB_FCKEDITOR			= 'fckeditor';
+	const LIB_MD5				= 'md5';
 	
 	// Javascriptライブラリ用のファイル
 	const JQUERY_EASING_FILENAME	= 'jquery/jquery.easing.1.3.js';
@@ -103,6 +104,7 @@ class PageManager
 	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.5.2.packed.js';				// JQuery UI Core (core+Interaction)
 	const JQUERY_UI_PLUS_FILENAME	= 'jquery-ui-plus-1.5.2.packed.js';				// JQuery UI Core (widgets+effects)
 	const FCKEDITOR_FILENAME		= 'fckeditor2.6/fckeditor.js';		// FCKEditor
+	const MD5_FILENAME				= 'md5.js';		// MD5
 	
 	// 設定ファイル
 	const FCKEDITOR_CONFIG			= 'm3/fckconfig.js';		// FCKEditor
@@ -143,7 +145,8 @@ class PageManager
 		$this->defaultAdminCssFiles = array();
 		
 		// Javascriptライブラリ
-		$this->libFiles = array(self::LIB_FCKEDITOR			=>	array(	'script' => array(self::FCKEDITOR_FILENAME)),	// FCKEditor
+		$this->libFiles = array(self::LIB_MD5				=>	array(	'script' => array(self::MD5_FILENAME)),			// MD5
+								self::LIB_FCKEDITOR			=>	array(	'script' => array(self::FCKEDITOR_FILENAME)),	// FCKEditor
 								self::LIB_JQUERY_UI_PLUS	=>	array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME)),	// jquery ui plus(追加分)
 								self::LIB_JQUERY_EASING		=>	array(	'script' => array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
 								self::LIB_JQUERY_JCAROUSEL	=>	array(	'script' => array(self::JQUERY_JCAROUSEL_FILENAME),// jquery.jcarousel用のファイル
@@ -759,7 +762,7 @@ class PageManager
 					$contents .= '<div id="preloader"><img src="' . $gEnvManager->getImagesUrl() . '/system/loader.gif" alt="" /></div>' . M3_NL;
 					$contents .= '</div>' . M3_NL;*/
 				
-					$contents .= '<script language="JavaScript">' . M3_NL;
+					$contents .= '<script type="text/javascript">' . M3_NL;
 					$contents .= '<!--' . M3_NL;
 				
 					// テンプレート上のポジション名
@@ -882,7 +885,7 @@ class PageManager
 							
 							// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 							if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();
-							echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+							echo '<script type="text/javascript" src="' . $scriptURL . '"></script>' . M3_NL;
 						}
 					}
 					$dir->close();
@@ -921,7 +924,7 @@ class PageManager
 //			echo '</div>' . M3_NL;
 			if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェット詳細設定画面のとき
 				if ($this->updateParentWindow){			// 親ウィンドウ再描画のとき
-					echo '<script language="JavaScript">' . M3_NL;
+					echo '<script type="text/javascript">' . M3_NL;
 					echo '<!--' . M3_NL;
 					echo '$(function(){' . M3_NL;
 					//echo 'm3UpdateParentWindow();' . M3_NL;
@@ -1061,17 +1064,17 @@ class PageManager
 					// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 					$scriptURL = $gEnvManager->getScriptsUrl() . '/' . $scriptFilename;
 					if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();
-					echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+					echo '<script type="text/javascript" src="' . $scriptURL . '"></script>' . M3_NL;
 				}
 				if ($cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){		// ウィジェット付きポジション表示のときは、ウィジェット操作ライブラリを読み込む
 					// wigetのドラッグドロップ用
 					$scriptURL = $gEnvManager->getScriptsUrl() . '/' . self::M3_ADMIN_WIDGET_SCRIPT_FILENAME;
 					if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();// スクリプトをキャッシュ保存しない場合は、パラメータを付加
-					echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+					echo '<script type="text/javascript" src="' . $scriptURL . '"></script>' . M3_NL;
 					// キー割付用
 					$scriptURL = $gEnvManager->getScriptsUrl() . '/' . self::JQUERY_JSHOTKEYS_FILENAME;
 					if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();// スクリプトをキャッシュ保存しない場合は、パラメータを付加
-					echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+					echo '<script type="text/javascript" src="' . $scriptURL . '"></script>' . M3_NL;
 				}
 			}
 		} else {			// 通常画面
@@ -1087,7 +1090,7 @@ class PageManager
 			
 				// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 				if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();
-				echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+				echo '<script type="text/javascript" src="' . $scriptURL . '"></script>' . M3_NL;
 			}
 		}
 		// ##### ウィジェットごとのJavaScript読み込み #####
@@ -1106,7 +1109,7 @@ class PageManager
 						$scriptURL = $gEnvManager->getWidgetsUrl() . '/' . $rows[$i]['wd_id'] . '/' . M3_DIR_NAME_SCRIPTS . '/' . $file;
 						// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 						if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();
-						echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+						echo '<script type="text/javascript" src="' . $scriptURL . '"></script>' . M3_NL;
 					}
 				}
 				$dir->close();
@@ -1114,7 +1117,7 @@ class PageManager
 		}
 		// ポップアップメッセージがある場合は表示
 		if (!empty($this->popupMsg)){
-			echo '<script language="JavaScript">' . M3_NL . '<!--' . M3_NL .  'alert("' . $this->popupMsg . '");' . M3_NL . '// -->' . M3_NL . '</script>';
+			echo '<script type="text/javascript">' . M3_NL . '<!--' . M3_NL .  'alert("' . $this->popupMsg . '");' . M3_NL . '// -->' . M3_NL . '</script>';
 		}
 		// ##### タグ変換用のタグを埋め込む #####
 		// ウィジェット単体実行のときはタグを埋め込まない
