@@ -140,20 +140,6 @@ CREATE TABLE wiki_content (
     UNIQUE               (wc_type,      wc_id,  wc_history_index)
 ) TYPE=innodb;
 
--- Wikiキャッシュマスター
-DROP TABLE IF EXISTS wiki_cache;
-CREATE TABLE wiki_cache (
-    wa_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    wa_type              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- コンテンツタイプ
-    wa_id                VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- コンテンツID
-    wa_data              TEXT                                         NOT NULL,      -- コンテンツ内容
-    
-    wa_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
-    wa_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
-    PRIMARY KEY          (wa_serial),
-    UNIQUE               (wa_type,      wa_id)
-) TYPE=innodb;
-
 -- ブログ設定マスター
 DROP TABLE IF EXISTS blog_config;
 CREATE TABLE blog_config (
