@@ -9,7 +9,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3admin_widget1.2.js 960 2008-08-30 09:12:23Z fishbone $
+ * @version    SVN: $Id: m3admin_widget1.3.0.js 986 2008-09-05 02:20:56Z fishbone $
  * @link       http://www.magic3.org
  */
 (function($){
@@ -326,7 +326,8 @@
 				
 				children = obj.children('.m3_widget_sortable');
 				
-				var spacerHtml = '<dl class="m3_widget_sortable m3_spacer" style="height:100px;border:0;"></dl>';
+				//var spacerHtml = '<dl class="m3_widget_sortable m3_spacer" style="height:100px;border:0;"></dl>';
+				var spacerHtml = '<div class="m3_spacer" style="height:100px;border:0;"></div>';// edit 2008.9.3
 				if (insertPos < children.length){
 					$(children[insertPos]).before(spacerHtml);
 				} else {
