@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCheckenvWidgetContainer.php 990 2008-09-06 07:39:40Z fishbone $
+ * @version    SVN: $Id: _installCheckenvWidgetContainer.php 1074 2008-10-11 10:49:19Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -101,6 +101,18 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_php_version", $data);
 		
+		// メモリ使用量のチェック
+		$data = '<b><font color="green">' . M3_SYSTEM_MIN_MEMORY . 'バイト以上を奨励</font></b>';
+		$this->tmpl->addVar("_widget","config_memory_limit", $data);
+		
+		$limit = ini_get('memory_limit');
+		if (convBytes($limit) >= convBytes(M3_SYSTEM_MIN_MEMORY)){
+			$data = '<b><font color="green">' . $limit . '</font></b>';
+		} else {
+			$data = '<b><font color="red">' . $limit . '</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_memory_limit", $data);
+		
 		// セーフモード
 		//$data = '<b><font color="green">off</font></b>';
 		$data = '<br>';
@@ -162,6 +174,15 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_mbstring_tran", $data);
 
+		// zlib
+		$data = '<b><font color="green">on</font></b>';
+		$this->tmpl->addVar("_widget","config_zlib", $data);
+		if (extension_loaded('zlib')){
+			$data = '<b><font color="green">on</font></b>';
+		} else {
+			$data = '<b><font color="red">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_zlib", $data);
 		// gd
 		$data = '<b><font color="green">on</font></b>';
 		$this->tmpl->addVar("_widget","config_gd", $data);
