@@ -1,6 +1,6 @@
 <?php
 // PukiWiki - Yet another WikiWikiWeb clone
-// $Id: pukiwiki.ini.php 1059 2008-10-06 08:55:26Z fishbone $
+// $Id: pukiwiki.ini.php 1084 2008-10-18 06:10:55Z fishbone $
 // Copyright (C)
 //   2002-2006 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -8,13 +8,72 @@
 //
 // PukiWiki main setting file
 // PukiWiki用グローバル変数		// add for Magic3 by naoki on 2008/10/6
-global $defaultpage;
+global $page_title;
+global $modifier;
+global $modifierlink;
+// pages
 global $whatsnew;
 global $whatsdeleted;
 global $interwiki;
-global $do_backup;
+
+global $nofollow;
+global $trackback;
+global $trackback_javascript;
+global $referer;
+global $nowikiname;
+global $autolink;
 global $function_freeze;
+global $notimeupdate;
+// auth
+global $auth_users;
+global $auth_method_type;
+global $read_auth;
+global $read_auth_pages;
+global $edit_auth;
+global $edit_auth_pages;
+global $search_auth;
+// page config
+global $maxshow;
+global $maxshow_deleted;
 global $cantedit;
+global $lastmod;
+global $date_format;
+global $time_format;
+global $rss_max;
+// backup
+global $do_backup;
+global $del_backup;
+// proxy
+global $use_proxy;
+global $proxy_host;
+global $proxy_port;
+global $need_proxy_auth;
+global $proxy_auth_user;
+global $proxy_auth_pass;
+global $no_proxy;
+// mail
+global $notify;
+global $notify_diff_only;
+global $smtp_server;
+global $notify_to;
+global $notify_from;
+global $notify_subject;
+global $notify_header;
+global $smtp_auth;
+global $pop_server;
+global $pop_port;
+global $pop_userid;
+global $pop_passwd;
+// other
+global $non_list;
+global $search_non_list;
+global $auto_template_func;
+global $auto_template_rules;
+global $fixed_heading_anchor;
+global $preformat_ltrim;
+global $line_break;
+global $usedatetime;
+global $agents;
 
 /////////////////////////////////////////////////
 // Functionality settings
@@ -136,7 +195,7 @@ $modifier = 'anonymous';
 $modifierlink = 'http://pukiwiki.example.com/';
 
 // Default page name
-$defaultpage  = 'FrontPage';     // Top / Default page
+//$defaultpage  = 'FrontPage';     // Top / Default page
 $whatsnew     = 'RecentChanges'; // Modified page list
 $whatsdeleted = 'RecentDeleted'; // Removeed page list
 $interwiki    = 'InterWikiName'; // Set InterWiki definition here
@@ -200,7 +259,7 @@ $notimeupdate = 1;
 // Admin password for this Wikisite
 
 // Default: always fail
-$adminpass = '{x-php-md5}!';
+//$adminpass = '{x-php-md5}!';
 
 // Sample:
 //$adminpass = 'pass'; // Cleartext
@@ -318,8 +377,8 @@ $do_backup = 1;
 $del_backup = 0;
 
 // Bacukp interval and generation
-$cycle  =   3; // Wait N hours between backup (0 = no wait)
-$maxage = 120; // Stock latest N backups
+//$cycle  =   3; // Wait N hours between backup (0 = no wait)
+//$maxage = 120; // Stock latest N backups
 
 // NOTE: $cycle x $maxage / 24 = Minimum days to lost your data
 //          3   x   120   / 24 = 15
