@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wiki_mainWidgetContainer.php 1075 2008-10-14 05:38:05Z fishbone $
+ * @version    SVN: $Id: wiki_mainWidgetContainer.php 1079 2008-10-15 10:58:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -119,7 +119,8 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 			WikiParam::setCmd('read');
 	
 			$arg = WikiParam::getUnbraketArg();
-			if ($arg == '') $arg = $defaultpage;
+			//if ($arg == '') $arg = $defaultpage;
+			if ($arg == '') $arg = WikiConfig::getDefaultPage();
 			WikiParam::setPage($arg);
 		}
 		// グローバル変数に値を格納
@@ -211,7 +212,7 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 		// タイトル表示制御
 		if (WikiConfig::isShowPageTitle()){
 			$this->tmpl->setAttribute('show_title', 'visibility', 'visible');
-			$this->tmpl->addVar("show_title", "title", $base);	// タイトル
+			$this->tmpl->addVar("show_title", "title", make_search($base));	// タイトル
 		}
 	}
 	/**
