@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wiki_mainDb.php 1073 2008-10-11 10:34:54Z fishbone $
+ * @version    SVN: $Id: wiki_mainDb.php 1081 2008-10-16 05:08:59Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -172,48 +172,95 @@ class wiki_mainDb extends BaseDb
 		return $ret;
 	}
 	/**
-	 * コンテンツ項目の削除
+	 * Wikiページその他データの更新
 	 *
-	 * @param string  $contentType	コンテンツタイプ
-	 * @param string  $contentId	コンテンツID(0のとき新規)
-	 * @param string  $lang			言語ID
-	 * @param int $userId			ユーザID(データ更新者)
-	 * @return						true=成功、false=失敗
+	 * @param string  $name			ウィキページ名
+	 * @param string  $data			データ
+	 * @param string  $type			ページタイプ
+	 * @return bool					true = 成功、false = 失敗
 	 */
-/*	function delContentItem($contentType, $contentId, $lang, $userId)
+	function updatePageOther($name, $data, $type)
 	{
+		global $gEnvManager;
+		
 		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
 		
 		// トランザクションスタート
 		$this->startTransaction();
-		
-		// 前レコードの削除状態チェック
-		$queryStr = 'SELECT * FROM content ';
-		$queryStr .=  'WHERE cn_type = ? ';
-		$queryStr .=    'AND cn_id = ? ';
-		$queryStr .=    'AND cn_language_id = ? ';
-		$queryStr .=  'ORDER BY cn_history_index DESC ';
-		$ret = $this->selectRecord($queryStr, array($contentType, $contentId, $lang), $row);
+
+		$queryStr = 'SELECT * FROM wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=    'AND wc_history_index = 0';
+		$ret = $this->selectRecord($queryStr, array($type, $name), $row);
 		if ($ret){
-			if ($row['cn_deleted']){		// レコードが削除されていれば終了
-				return false;
-			}
+			$queryStr  = 'UPDATE wiki_content ';
+			$queryStr .=   'SET wc_data = ?, ';
+			$queryStr .=     'wc_update_user_id = ?, ';
+			$queryStr .=     'wc_update_dt = ? ';
+			$queryStr .=   'WHERE wc_serial = ?';
+			$this->execStatement($queryStr, array($data, $userId, $now, $row['wc_serial']));			
 		} else {
-			return false;
+			$queryStr  = 'INSERT INTO wiki_content (';
+			$queryStr .=   'wc_type, ';
+			$queryStr .=   'wc_id, ';
+			$queryStr .=   'wc_data, ';
+			$queryStr .=   'wc_create_user_id, ';
+			$queryStr .=   'wc_create_dt ';
+			$queryStr .= ') VALUES (';
+			$queryStr .=   '?, ?, ?, ?, ?';
+			$queryStr .= ')';
+			$this->execStatement($queryStr, array($type, $name, $data, $userId, $now));	
 		}
-			
-		// 古いレコードを削除
-		$queryStr  = 'UPDATE content ';
-		$queryStr .=   'SET cn_deleted = true, ';	// 削除
-		$queryStr .=     'cn_update_user_id = ?, ';
-		$queryStr .=     'cn_update_dt = ? ';
-		$queryStr .=   'WHERE cn_serial = ?';
-		$ret = $this->execStatement($queryStr, array($userId, $now, $row['cn_serial']));
+		// トランザクション終了
+		$ret = $this->endTransaction();
+		return $ret;
+	}
+	/**
+	 * Wikiページその他データを取得
+	 *
+	 * @param string  $name			ウィキページ名
+	 * @param string  $type			ページタイプ
+	 * @return string				取得値
+	 */
+	function getPageOther($name, $type)
+	{
+		$queryStr = 'SELECT * FROM wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=    'AND wc_history_index = 0';
+		$ret = $this->selectRecord($queryStr, array($type, $name), $row);
+		if ($ret){
+			return $row['wc_data'];
+		} else {
+			return '';
+		}
+	}
+	/**
+	 * Wikiページその他データを削除
+	 *
+	 * @param string $name			ページ名(空文字列のときは同じタイプのデータをすべて削除)
+	 * @param string  $type			ページタイプ
+	 * @return bool					true = 成功、false = 失敗
+	 */
+	function clearPageOther($name, $type)
+	{
+		// トランザクションスタート
+		$this->startTransaction();
+		
+		$param = array();
+		$queryStr  = 'DELETE FROM wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? '; $param[] = $type;
+		if (!empty($name)){
+			$queryStr .=  'AND wc_id = ? '; $param[] = $name;
+		}
+		$this->execStatement($queryStr, $param);
 		
 		// トランザクション終了
 		$ret = $this->endTransaction();
 		return $ret;
-	}*/
+	}
 	/**
 	 * 設定値が存在するかチェック
 	 *
