@@ -1,6 +1,18 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: file.php 1068 2008-10-10 11:46:46Z fishbone $
+/**
+ * ファイル管理ライブラリ
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: file.php 1084 2008-10-18 06:10:55Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2002-2006 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -10,10 +22,10 @@
 
 // RecentChanges
 define('PKWK_MAXSHOW_ALLOWANCE', 10);
-define('PKWK_MAXSHOW_CACHE', 'recent.dat');
+//define('PKWK_MAXSHOW_CACHE', 'recent.dat');
 
 // AutoLink
-define('PKWK_AUTOLINK_REGEX_CACHE', 'autolink.dat');
+//define('PKWK_AUTOLINK_REGEX_CACHE', 'autolink.dat');
 
 // Get source(wiki text) data of the page
 // modified for Magic3 by naoki on 2008/9/28
@@ -68,25 +80,68 @@ function get_filename($page)
 }
 
 // Put a data(wiki text) into a physical file(diff, backup, text)
+// modified for Magic3 by naoki on 2008/10/15
 function page_write($page, $postdata, $notimestamp = FALSE)
 {
 	global $trackback;
+	global $notify, $notify_diff_only, $notify_subject;
 
 	if (PKWK_READONLY) return; // Do nothing
 
 	$postdata = make_str_rules($postdata);
 
 	// Create and write diff
-	$oldpostdata = is_page($page) ? join('', get_source($page)) : '';
+	//$oldpostdata = is_page($page) ? join('', get_source($page)) : '';
+	$oldpostdata = is_page($page) ? get_source($page, true) : '';
 	$diffdata    = do_diff($oldpostdata, $postdata);
-	file_write(DIFF_DIR, $page, $diffdata);
+
+	// ページdiffデータ更新
+	//file_write(DIFF_DIR, $page, $diffdata);
+	if ($diffdata != " \n"){
+		$diffdata = rtrim(preg_replace('/' . "\r" . '/', '', $diffdata)) . "\n";
+		WikiPage::updatePageDiff($page, $diffdata);
+		
+		if ($notify){
+			if ($notify_diff_only) $diffdata = preg_replace('/^[^-+].*\n/m', '', $diffdata);
+			$footer['ACTION'] = 'Page update';
+			$footer['PAGE']   = $page;
+			$footer['URI']    = get_script_uri() . WikiParam::convQuery('?' . rawurlencode($page));
+			$footer['USER_AGENT']  = TRUE;
+			$footer['REMOTE_ADDR'] = TRUE;
+			pkwk_mail_notify($notify_subject, $diffdata, $footer) or die('pkwk_mail_notify(): Failed');
+		}
+	}
 
 	// Create backup
-	make_backup($page, $postdata == ''); // Is $postdata null?
+	//make_backup($page, $postdata == ''); // Is $postdata null?
 
 	// Create wiki text
-	file_write(DATA_DIR, $page, $postdata, $notimestamp);
+	//file_write(DATA_DIR, $page, $postdata, $notimestamp);
+	if ($postdata === ''){		// データが空のときはページを削除
+		if (! $file_exists) return; // Ignore null posting for DATA_DIR
 
+		// Update RecentDeleted (Add the $page)
+		add_recent($page, $whatsdeleted, '', $maxshow_deleted);
+
+		// Remove the page
+		unlink($file);
+
+		// Update RecentDeleted, and remove the page from RecentChanges
+		lastmodified_add($whatsdeleted, $page);
+	} else {		// 更新データがあるときはデータを更新
+		$postdata = rtrim(preg_replace('/' . "\r" . '/', '', $postdata)) . "\n";
+		
+		$ret = WikiPage::updatePage($page, $postdata, $notimestamp);
+
+		// Update RecentChanges (Add or renew the $page)
+		if ($notimestamp === FALSE) lastmodified_add($page);
+	}
+	// キャッシュクリア
+	is_page($page, TRUE); // Clear is_page() cache
+	
+	// リンクを更新
+	links_update($page);
+	
 	if ($trackback) {
 		// TrackBack Ping
 		$_diff = explode("\n", $diffdata);
@@ -94,8 +149,6 @@ function page_write($page, $postdata, $notimestamp = FALSE)
 		$minus = join("\n", preg_replace('/^-/',  '', preg_grep('/^-/',  $_diff)));
 		tb_send($page, $plus, $minus);
 	}
-
-	links_update($page);
 }
 
 // Modify original text with user-defined / system-defined rules
@@ -168,6 +221,7 @@ function generate_fixed_heading_anchor_id($seed)
 
 // Read top N lines as an array
 // (Use PHP file() function if you want to get ALL lines)
+// ######### 未使用関数 ######### for magic3
 function file_head($file, $count = 1, $lock = TRUE, $buffer = 8192)
 {
 	$array = array();
@@ -190,6 +244,7 @@ function file_head($file, $count = 1, $lock = TRUE, $buffer = 8192)
 }
 
 // Output to a file
+// ######### 未使用関数 ######### for magic3
 function file_write($dir, $page, $str, $notimestamp = FALSE)
 {
 	global $_msg_invalidiwn, $notify, $notify_diff_only, $notify_subject;
@@ -204,7 +259,7 @@ function file_write($dir, $page, $str, $notimestamp = FALSE)
 
 	// ----
 	// Delete?
-	// ݒf[^̂Ƃ̓y[W폜
+	// 設定データが空のときはページを削除
 	if ($dir == DATA_DIR && $str === '') {
 		// Page deletion
 		if (! $file_exists) return; // Ignore null posting for DATA_DIR
@@ -251,7 +306,7 @@ function file_write($dir, $page, $str, $notimestamp = FALSE)
 	flock($fp, LOCK_UN);
 	fclose($fp);
 
-	if ($timestamp) pkwk_touch_file($file, $timestamp);		// ێ^CX^vŕۑ
+	if ($timestamp) pkwk_touch_file($file, $timestamp);		// 保持したタイムスタンプで保存
 	*/
 	$ret = WikiPage::updatePage($page, $str, $notimestamp);
 
@@ -281,8 +336,7 @@ function file_write($dir, $page, $str, $notimestamp = FALSE)
 // Update RecentDeleted
 function add_recent($page, $recentpage, $subject = '', $limit = 0)
 {
-	if (PKWK_READONLY || $limit == 0 || $page == '' || $recentpage == '' ||
-	    check_non_list($page)) return;
+	if (PKWK_READONLY || $limit == 0 || $page == '' || $recentpage == '' || check_non_list($page)) return;
 
 	// Load
 	$lines = $matches = array();
@@ -302,6 +356,7 @@ function add_recent($page, $recentpage, $subject = '', $limit = 0)
 	// Get latest $limit reports
 	$lines = array_splice($lines, 0, $limit);
 
+	/*
 	// Update
 	$fp = fopen(get_filename($recentpage), 'w') or
 		die_message('Cannot write page file ' .
@@ -315,13 +370,20 @@ function add_recent($page, $recentpage, $subject = '', $limit = 0)
 	fputs($fp, join('', $lines));
 	flock($fp, LOCK_UN);
 	fclose($fp);
+	*/
+	// ページを更新
+	$newData = '';
+	$newData .= '#norelated' . "\n";
+	$newData .= join('', $lines);
+	$ret = WikiPage::updatePage($recentpage, $newData);
 }
 
 // Update PKWK_MAXSHOW_CACHE itself (Add or renew about the $page) (Light)
 // Use without $autolink
 function lastmodified_add($update = '', $remove = '')
 {
-	global $maxshow, $whatsnew, $autolink;
+	//global $maxshow, $whatsnew, $autolink;
+	global $maxshow, $autolink;
 
 	// AutoLink implimentation needs everything, for now
 	if ($autolink) {
@@ -332,24 +394,36 @@ function lastmodified_add($update = '', $remove = '')
 	if (($update == '' || check_non_list($update)) && $remove == '')
 		return; // No need
 
-	$file = CACHE_DIR . PKWK_MAXSHOW_CACHE;
+/*	$file = CACHE_DIR . PKWK_MAXSHOW_CACHE;
 	if (! file_exists($file)) {
 		put_lastmodified(); // Try to (re)create ALL
 		return;
+	}*/
+	// 最終更新データを取得
+	$lines = WikiPage::getCacheRecentChanges();
+	if (empty($lines)){
+		put_lastmodified();			// 最終更新データを再作成
+		return;
 	}
 
 	// Open
-	pkwk_touch_file($file);
+	/*pkwk_touch_file($file);
 	$fp = fopen($file, 'r+') or
 		die_message('Cannot open ' . 'CACHE_DIR/' . PKWK_MAXSHOW_CACHE);
 	set_file_buffer($fp, 0);
-	flock($fp, LOCK_EX);
+	flock($fp, LOCK_EX);*/
 
 	// Read (keep the order of the lines)
 	$recent_pages = $matches = array();
-	foreach(file_head($file, $maxshow + PKWK_MAXSHOW_ALLOWANCE, FALSE) as $line)
+	/*foreach(file_head($file, $maxshow + PKWK_MAXSHOW_ALLOWANCE, FALSE) as $line)
 		if (preg_match('/^([0-9]+)\t(.+)/', $line, $matches))
+			$recent_pages[$matches[2]] = $matches[1];*/
+	$lineCount = $maxshow + PKWK_MAXSHOW_ALLOWANCE < count($lines) ? $maxshow + PKWK_MAXSHOW_ALLOWANCE : count($lines);
+	for ($i = 0; $i < $lineCount; $i++){
+		if (preg_match('/^([0-9]+)\t(.+)/', $lines[$i], $matches)){
 			$recent_pages[$matches[2]] = $matches[1];
+		}
+	}
 
 	// Remove if it exists inside
 	if (isset($recent_pages[$update])) unset($recent_pages[$update]);
@@ -364,25 +438,26 @@ function lastmodified_add($update = '', $remove = '')
 
 	if (! $abort) {
 		// Write
-		ftruncate($fp, 0);
+		/*ftruncate($fp, 0);
 		rewind($fp);
 		foreach ($recent_pages as $_page=>$time)
-			fputs($fp, $time . "\t" . $_page . "\n");
+			fputs($fp, $time . "\t" . $_page . "\n");*/
+		$newData = '';
+		foreach ($recent_pages as $_page=>$time){
+			$newData .= $time . "\t" . $_page . "\n";
+		}
+		WikiPage::updateCacheRecentChanges($newData);
 	}
 
-	flock($fp, LOCK_UN);
-	fclose($fp);
+	/*flock($fp, LOCK_UN);
+	fclose($fp);*/
 
 	if ($abort) {
 		put_lastmodified(); // Try to (re)create ALL
 		return;
 	}
-
-
-
-	// ----
+	/*
 	// Update the page 'RecentChanges'
-
 	$recent_pages = array_splice($recent_pages, 0, $maxshow);
 	$file = get_filename($whatsnew);
 
@@ -403,6 +478,17 @@ function lastmodified_add($update = '', $remove = '')
 
 	flock($fp, LOCK_UN);
 	fclose($fp);
+	*/
+	
+	// 最終更新ページを更新
+	$recent_pages = array_splice($recent_pages, 0, $maxshow);
+	
+	$newData = '';
+	foreach ($recent_pages as $_page=>$time){
+		$newData .= '-' . htmlspecialchars(format_date($time)) . ' - ' . '[[' . htmlspecialchars($_page) . ']]' . "\n";
+	}
+	$newData .= '#norelated' . "\n";
+	WikiPage::updatePage(WikiConfig::getWhatsnewPage(), $newData);
 }
 
 // Re-create PKWK_MAXSHOW_CACHE (Heavy)
@@ -433,8 +519,9 @@ function put_lastmodified()
 		$_recent[$key] = $value;
 		if (--$count < 1) break;
 	}
-	$recent_pages = & $_recent;
+	$recent_pages = $_recent;
 
+/*
 	// Re-create PKWK_MAXSHOW_CACHE
 	$file = CACHE_DIR . PKWK_MAXSHOW_CACHE;
 	pkwk_touch_file($file);
@@ -447,8 +534,16 @@ function put_lastmodified()
 	foreach ($recent_pages as $page=>$time)
 		fputs($fp, $time . "\t" . $page . "\n");
 	flock($fp, LOCK_UN);
-	fclose($fp);
-
+	fclose($fp);*/
+	
+	// 最終更新データを更新
+	$newData = '';
+	foreach ($recent_pages as $page=>$time){
+		$newData .= $time . "\t" . $page . "\n";
+	}
+	WikiPage::updateCacheRecentChanges($newData);
+		
+/*
 	// Create RecentChanges
 	$file = get_filename($whatsnew);
 	pkwk_touch_file($file);
@@ -466,13 +561,24 @@ function put_lastmodified()
 	}
 	fputs($fp, '#norelated' . "\n"); // :)
 	flock($fp, LOCK_UN);
-	fclose($fp);
+	fclose($fp);*/
+	
+	// 最終更新ページを更新
+	$newData = '';
+	foreach (array_keys($recent_pages) as $page) {
+		$time      = $recent_pages[$page];
+		$s_lastmod = htmlspecialchars(format_date($time));
+		$s_page    = htmlspecialchars($page);
+		$newData .= '-' . $s_lastmod . ' - [[' . $s_page . ']]' . "\n";
+	}
+	$newData .= '#norelated' . "\n";
+	WikiPage::updatePage(WikiConfig::getWhatsnewPage(), $newData);	
 
 	// For AutoLink
 	if ($autolink) {
-		list($pattern, $pattern_a, $forceignorelist) =
-			get_autolink_pattern($pages);
+		list($pattern, $pattern_a, $forceignorelist) = get_autolink_pattern($pages);
 
+/*
 		$file = CACHE_DIR . PKWK_AUTOLINK_REGEX_CACHE;
 		pkwk_touch_file($file);
 		$fp = fopen($file, 'r+') or
@@ -485,7 +591,13 @@ function put_lastmodified()
 		fputs($fp, $pattern_a . "\n");
 		fputs($fp, join("\t", $forceignorelist) . "\n");
 		flock($fp, LOCK_UN);
-		fclose($fp);
+		fclose($fp);*/
+		// 自動リンクデータを更新
+		$newData = '';
+		$newData .= $pattern   . "\n";
+		$newData .= $pattern_a . "\n";
+		$newData .= join("\t", $forceignorelist) . "\n";
+		WikiPage::updateCacheAutolink($newData);
 	}
 }
 
@@ -517,7 +629,7 @@ function header_lastmod($page = NULL)
 function get_existpages($dir = DATA_DIR, $ext = '.txt')
 {
 	// comment for Magic3 by naoki on 2008/9/30
-	// $extɗĺAu.txtv(ʏ̃y[W),u.refv(LbV),u.countv(y[WQƐ),u.gzv(obNAbv)
+	// $extに来る値は、「.txt」(通常のページ),「.ref」(キャッシュ),「.count」(ページ参照数),「.gz」(バックアップ)
 	
 	// modified for Magic3 by naoki on 2008/9/30
 	//$aryret = array();
@@ -716,16 +828,19 @@ function get_existfiles($dir, $ext)
 // Get a list of related pages of the page
 function links_get_related($page)
 {
-	global $vars, $related;
+	//global $vars, $related;
+	global $related;
 	static $links = array();
 
 	if (isset($links[$page])) return $links[$page];
 
 	// If possible, merge related pages generated by make_link()
-	$links[$page] = ($page == $vars['page']) ? $related : array();
+	//$links[$page] = ($page == $vars['page']) ? $related : array();
+	$links[$page] = ($page == WikiParam::getPage()) ? $related : array();
 
 	// Get repated pages from DB
-	$links[$page] += links_get_related_db($vars['page']);
+	//$links[$page] += links_get_related_db($vars['page']);
+	$links[$page] += links_get_related_db(WikiParam::getPage());
 
 	return $links[$page];
 }
@@ -790,6 +905,7 @@ function pkwk_chown($filename, $preserve_time = TRUE)
 }
 
 // touch() with trying pkwk_chown()
+// ######### 未使用関数 ######### for magic3
 function pkwk_touch_file($filename, $time = FALSE, $atime = FALSE)
 {
 	// Is the owner incorrected and unable to correct?
