@@ -1,6 +1,18 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: func.php 1063 2008-10-08 10:36:47Z fishbone $
+/**
+ * 共通関数ライブラリ
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: func.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2002-2006 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -290,9 +302,8 @@ function do_search($word, $type = 'AND', $non_format = FALSE, $base = '')
 		$r_page  = rawurlencode($page);
 		$s_page  = htmlspecialchars($page);
 		$passage = $show_passage ? ' ' . get_passage(get_filetime($page)) : '';
-		$retval .= ' <li><a href="' . $script . '?cmd=read&amp;page=' .
-			$r_page . '&amp;word=' . $r_word . '">' . $s_page .
-			'</a>' . $passage . '</li>' . "\n";
+		//$retval .= ' <li><a href="' . $script . '?cmd=read&amp;page=' . $r_page . '&amp;word=' . $r_word . '">' . $s_page . '</a>' . $passage . '</li>' . "\n";
+		$retval .= ' <li><a href="' . $script . WikiParam::convQuery('?cmd=read&amp;page=' . $r_page . '&amp;word=' . $r_word) . '">' . $s_page . '</a>' . $passage . '</li>' . "\n";
 	}
 	$retval .= '</ul>' . "\n";
 
@@ -365,9 +376,11 @@ function page_list($pages, $cmd = 'read', $withfilename = FALSE)
 
 	// Shrink URI for read
 	if ($cmd == 'read') {
-		$href = $script . '?';
+		//$href = $script . '?';
+		$query = '?';
 	} else {
-		$href = $script . '?cmd=' . $cmd . '&amp;page=';
+		//$href = $script . '?cmd=' . $cmd . '&amp;page=';
+		$query = '?cmd=' . $cmd . '&amp;page=';
 	}
 
 	foreach($pages as $file=>$page) {
@@ -375,8 +388,8 @@ function page_list($pages, $cmd = 'read', $withfilename = FALSE)
 		$s_page  = htmlspecialchars($page, ENT_QUOTES);
 		$passage = get_pg_passage($page);
 
-		$str = '   <li><a href="' . $href . $r_page . '">' .
-			$s_page . '</a>' . $passage;
+		//$str = '   <li><a href="' . $href . $r_page . '">' . $s_page . '</a>' . $passage;
+		$str = '   <li><a href="' . $script . WikiParam::convQuery($query . $r_page) . '">' . $s_page . '</a>' . $passage;
 
 		if ($withfilename) {
 			$s_file = htmlspecialchars($file);
