@@ -1,6 +1,18 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: init.php 1075 2008-10-14 05:38:05Z fishbone $
+/**
+ * 初期化ライブラリ
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: init.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2002-2006 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -217,7 +229,8 @@ unset($die, $temp);
 
 /////////////////////////////////////////////////
 // 必須のページが存在しなければ、空のファイルを作成する
-foreach(array($defaultpage, $whatsnew, $interwiki) as $page){
+//foreach(array($defaultpage, $whatsnew, $interwiki) as $page){
+foreach(array(WikiConfig::getDefaultPage(), $whatsnew, $interwiki) as $page){
 	//if (! is_page($page)) touch(get_filename($page));
 	// modified for Magic3 by naoki on 2008/9/22
 	if (!WikiPage::isPage($page)){
