@@ -1,6 +1,18 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone
-// $Id: link.php 1038 2008-09-23 07:31:04Z fishbone $
+/**
+ * link管理ライブラリ
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: link.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C) 2003-2006 PukiWiki Developers Team
 // License: GPL v2 or (at your option) any later version
 //
@@ -28,15 +40,17 @@
 
 // ------------------------------------------------------------
 
-
+// modified for Magic3 by naoki on 2008/10/15
 // データベースから関連ページを得る
 function links_get_related_db($page)
 {
-	$ref_name = CACHE_DIR . encode($page) . '.ref';
-	if (! file_exists($ref_name)) return array();
+	//$ref_name = CACHE_DIR . encode($page) . '.ref';
+	//if (! file_exists($ref_name)) return array();
+	$refPage = WikiPage::getPageCacheRef($page);
 
 	$times = array();
-	foreach (file($ref_name) as $line) {
+	//foreach (file($ref_name) as $line) {
+	foreach ($refPage as $line){
 		list($_page) = explode("\t", rtrim($line));
 		$time = get_filetime($_page);	
 		if($time != 0) $times[$_page] = $time;
@@ -45,15 +59,16 @@ function links_get_related_db($page)
 }
 
 //ページの関連を更新する
+// modified for Magic3 by naoki on 2008/10/15
 function links_update($page)
 {
 	if (PKWK_READONLY) return; // Do nothing
 
-	if (ini_get('safe_mode') == '0') set_time_limit(0);
+	//if (ini_get('safe_mode') == '0') set_time_limit(0);
 
-	$time = is_page($page, TRUE) ? get_filetime($page) : 0;
+	//$time = is_page($page, TRUE) ? get_filetime($page) : 0;
 
-	$rel_old        = array();
+	/*$rel_old        = array();
 	$rel_file       = CACHE_DIR . encode($page) . '.rel';
 	$rel_file_exist = file_exists($rel_file);
 	if ($rel_file_exist === TRUE) {
@@ -61,7 +76,9 @@ function links_update($page)
 		unlink($rel_file);
 		if (isset($lines[0]))
 			$rel_old = explode("\t", rtrim($lines[0]));
-	}
+	}*/
+	$rel_old = explode("\t", WikiPage::getPageCacheRel($page, true));
+	
 	$rel_new  = array(); // 参照先
 	$rel_auto = array(); // オートリンクしている参照先
 	$links    = links_get_objects($page, TRUE);
@@ -85,16 +102,18 @@ function links_update($page)
 	$rel_new = array_merge($rel_new, $rel_auto);
 
 	// .rel:$pageが参照しているページの一覧
-	if ($time) {
+	/*if ($time) {
 		// ページが存在している
-		if (! empty($rel_new)) {
-    			$fp = fopen($rel_file, 'w')
+		if (!empty($rel_new)){
+    		$fp = fopen($rel_file, 'w')
     				or die_message('cannot write ' . htmlspecialchars($rel_file));
 			fputs($fp, join("\t", $rel_new));
 			fclose($fp);
 		}
-	}
-
+	}*/
+	// キャッシュを更新
+	if (!empty($rel_new)) WikiPage::updatePageCacheRel($page, join("\t", $rel_new));
+	
 	// .ref:$_pageを参照しているページの一覧
 	links_add($page, array_diff($rel_new, $rel_old), $rel_auto);
 	links_delete($page, array_diff($rel_old, $rel_new));
@@ -102,8 +121,9 @@ function links_update($page)
 	global $WikiName, $autolink, $nowikiname, $search_non_list;
 
 	// $pageが新規作成されたページで、AutoLinkの対象となり得る場合
-	if ($time && ! $rel_file_exist && $autolink
-		&& (preg_match("/^$WikiName$/", $page) ? $nowikiname : strlen($page) >= $autolink))
+	/*if ($time && ! $rel_file_exist && $autolink
+		&& (preg_match("/^$WikiName$/", $page) ? $nowikiname : strlen($page) >= $autolink))*/
+	if ($autolink && (preg_match("/^$WikiName$/", $page) ? $nowikiname : strlen($page) >= $autolink))
 	{
 		// $pageを参照していそうなページを一斉更新する(おい)
 		$search_non_list = 1;
@@ -113,20 +133,22 @@ function links_update($page)
 				links_update($_page);
 		}
 	}
-	$ref_file = CACHE_DIR . encode($page) . '.ref';
+	//$ref_file = CACHE_DIR . encode($page) . '.ref';
 
 	// $pageが削除されたときに、
-	if (! $time && file_exists($ref_file)) {
-		foreach (file($ref_file) as $line) {
+	//if (! $time && file_exists($ref_file)) {
+	if (!WikiPage::isPage($page)){
+		//foreach (file($ref_file) as $line) {
+		$refPage = WikiPage::getPageCacheRef($page);
+		foreach ($refPage as $line){
 			list($ref_page, $ref_auto) = explode("\t", rtrim($line));
 
 			// $pageをAutoLinkでしか参照していないページを一斉更新する(おいおい)
-			if ($ref_auto)
-				links_delete($ref_page, array($page));
+			if ($ref_auto) links_delete($ref_page, array($page));
 		}
 	}
 }
-
+// modified for Magic3 by naoki on 2008/10/15
 // Init link cache (Called from link plugin)
 function links_init()
 {
@@ -134,13 +156,16 @@ function links_init()
 
 	if (PKWK_READONLY) return; // Do nothing
 
-	if (ini_get('safe_mode') == '0') set_time_limit(0);
+	//if (ini_get('safe_mode') == '0') set_time_limit(0);
 
 	// Init database
-	foreach (get_existfiles(CACHE_DIR, '.ref') as $cache)
+	/*foreach (get_existfiles(CACHE_DIR, '.ref') as $cache)
 		unlink($cache);
 	foreach (get_existfiles(CACHE_DIR, '.rel') as $cache)
-		unlink($cache);
+		unlink($cache);*/
+	// キャッシュクリア
+	WikiPage::clearCacheRef();
+	WikiPage::clearCacheRel();
 
 	$ref   = array(); // 参照元
 	foreach (get_existpages() as $page) {
@@ -160,23 +185,27 @@ function links_init()
 				$ref[$_obj->name][$page] = 0;
 		}
 		$rel = array_unique($rel);
-		if (! empty($rel)) {
-			$fp = fopen(CACHE_DIR . encode($page) . '.rel', 'w')
+		if (!empty($rel)){
+			/*$fp = fopen(CACHE_DIR . encode($page) . '.rel', 'w')
 				or die_message('cannot write ' . htmlspecialchars(CACHE_DIR . encode($page) . '.rel'));
 			fputs($fp, join("\t", $rel));
-			fclose($fp);
+			fclose($fp);*/
+			WikiPage::updatePageCacheRel($page, join("\t", $rel));
 		}
 	}
 
 	foreach ($ref as $page=>$arr) {
-		$fp  = fopen(CACHE_DIR . encode($page) . '.ref', 'w')
+		/*$fp  = fopen(CACHE_DIR . encode($page) . '.ref', 'w')
 			or die_message('cannot write ' . htmlspecialchars(CACHE_DIR . encode($page) . '.ref'));
 		foreach ($arr as $ref_page=>$ref_auto)
 			fputs($fp, $ref_page . "\t" . $ref_auto . "\n");
-		fclose($fp);
+		fclose($fp);*/
+		foreach ($arr as $ref_page=>$ref_auto){
+			WikiPage::updatePageCacheRef($page, $ref_page . "\t" . $ref_auto . "\n");
+		}
 	}
 }
-
+// modified for Magic3 by naoki on 2008/10/15
 function links_add($page, $add, $rel_auto)
 {
 	if (PKWK_READONLY) return; // Do nothing
@@ -188,7 +217,7 @@ function links_add($page, $add, $rel_auto)
 		$is_page  = is_page($_page);
 		$ref      = $page . "\t" . ($all_auto ? 1 : 0) . "\n";
 
-		$ref_file = CACHE_DIR . encode($_page) . '.ref';
+		/*$ref_file = CACHE_DIR . encode($_page) . '.ref';
 		if (file_exists($ref_file)) {
 			foreach (file($ref_file) as $line) {
 				list($ref_page, $ref_auto) = explode("\t", rtrim($line));
@@ -196,46 +225,65 @@ function links_add($page, $add, $rel_auto)
 				if ($ref_page != $page) $ref .= $line;
 			}
 			unlink($ref_file);
+		}*/
+		$refPage = WikiPage::getPageCacheRef($page);
+		foreach ($refPage as $line){
+			list($ref_page, $ref_auto) = explode("\t", rtrim($line));
+			if (! $ref_auto) $all_auto = FALSE;
+			if ($ref_page != $page) $ref .= $line;
 		}
-		if ($is_page || ! $all_auto) {
+		/*if ($is_page || ! $all_auto) {
 			$fp = fopen($ref_file, 'w')
 				 or die_message('cannot write ' . htmlspecialchars($ref_file));
 			fputs($fp, $ref);
 			fclose($fp);
+		}*/
+		if ($is_page || !$all_auto){
+			WikiPage::updatePageCacheRef($page, $ref);
+		} else {
+			WikiPage::updatePageCacheRef($page, '');
 		}
 	}
 }
-
+// modified for Magic3 by naoki on 2008/10/15
 function links_delete($page, $del)
 {
 	if (PKWK_READONLY) return; // Do nothing
 
 	foreach ($del as $_page) {
-		$ref_file = CACHE_DIR . encode($_page) . '.ref';
-		if (! file_exists($ref_file)) continue;
+		//$ref_file = CACHE_DIR . encode($_page) . '.ref';
+		//if (! file_exists($ref_file)) continue;
+		$refPage = WikiPage::getPageCacheRef($page);
+		if (empty($refPage)) continue;
 
 		$all_auto = TRUE;
 		$is_page = is_page($_page);
 
 		$ref = '';
-		foreach (file($ref_file) as $line) {
+		//foreach (file($ref_file) as $line) {
+		foreach ($refPage as $line) {
 			list($ref_page, $ref_auto) = explode("\t", rtrim($line));
 			if ($ref_page != $page) {
 				if (! $ref_auto) $all_auto = FALSE;
 				$ref .= $line;
 			}
 		}
-		unlink($ref_file);
+		/*unlink($ref_file);
 		if (($is_page || ! $all_auto) && $ref != '') {
 			$fp = fopen($ref_file, 'w')
 				or die_message('cannot write ' . htmlspecialchars($ref_file));
 			fputs($fp, $ref);
 			fclose($fp);
+		}*/
+		if (($is_page || !$all_auto) && $ref != ''){
+			WikiPage::updatePageCacheRef($page, $ref);
+		} else {
+			WikiPage::updatePageCacheRef($page, '');
 		}
 	}
 }
 
-function & links_get_objects($page, $refresh = FALSE)
+function links_get_objects($page, $refresh = FALSE)
 {
 	static $obj;
 
