@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wikiConfig.php 1075 2008-10-14 05:38:05Z fishbone $
+ * @version    SVN: $Id: wikiConfig.php 1077 2008-10-14 09:59:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/wiki_mainDb.php');
@@ -22,9 +22,12 @@ class WikiConfig
 	private static $isShowToolbarForAllUser;	// 全ユーザ向けにツールバーを表示するかどうか
 	private static $isShowPageTitle;				// ページタイトルを表示するかどうか
 	const SHOW_TOOLBAR_FOR_ALL_USER = 'show_toolbar_for_all_user';
-	const CONFIG_KEY_AUTH_TYPE = 'auth_type';			// 認証タイプ(0=管理権限ユーザ、1=ログインユーザ、2=共通パスワード)
+	const DEFAULT_AUTH_TYPE = 'admin';		// デフォルトの認証タイプ
+	const DEFAULT_PAGE = 'FrontPage';		// デフォルトのページ
+	const CONFIG_KEY_AUTH_TYPE = 'auth_type';			// 認証タイプ(admin=管理権限ユーザ、loginuser=ログインユーザ、password=共通パスワード)
 	const CONFIG_KEY_SHOW_PAGE_TITLE = 'show_page_title';
 	const CONFIG_KEY_PASSWORD = 'password';		// 共通パスワード
+	const CONFIG_KEY_DEFAULT_PAGE = 'default_page';		// デフォルトページ
 	
 	/**
 	 * コンストラクタ
@@ -40,13 +43,25 @@ class WikiConfig
 	 */
 	public static function init($db)
 	{
+		global $defaultpage;
 		self::$db = $db;
 		
 		// 設定値を取得
 		$value = self::$db->getConfig(self::SHOW_TOOLBAR_FOR_ALL_USER);		// 全ユーザ向けにツールバーを表示するかどうか
 		if (!empty($value)) self::$isShowToolbarForAllUser = true;
 		$value = self::$db->getConfig(self::CONFIG_KEY_SHOW_PAGE_TITLE);		// ページタイトルを表示するかどうか
-		if (!empty($value)) self::$isShowPageTitle = true;
+		if ($value == ''){
+			self::$isShowPageTitle = true;
+		} else {
+			if (!empty($value)) self::$isShowPageTitle = true;
+		}
+		$value = self::$db->getConfig(self::CONFIG_KEY_DEFAULT_PAGE);// デフォルトページ
+		if (empty($value)){
+			self::$defaultPage = self::DEFAULT_PAGE;
+		} else {
+			self::$defaultPage = $value;
+		}
+		$defaultpage = self::$defaultPage;
 	}
 	/**
 	 * デフォルトのページ名を取得
@@ -55,8 +70,7 @@ class WikiConfig
 	 */
 	public static function getDefaultPage()
 	{
-		global $defaultpage;
-		return $defaultpage;
+		return self::$defaultPage;
 	}
 	/**
 	 * 「編集されたページ」のページ名を取得
