@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wikiParam.php 1071 2008-10-11 10:15:12Z fishbone $
+ * @version    SVN: $Id: wikiParam.php 1083 2008-10-17 15:35:10Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/wiki_mainDb.php');
@@ -196,6 +196,25 @@ class WikiParam
 	{
 		self::$msg = $value;
 	}
+	/**
+	 * レファラー値を取得
+	 *
+	 * @return string	レファラー値
+	 */
+	public static function getRefer()
+	{
+		return self::$refer;
+	}
+	/**
+	 * レファラー値を設定
+	 *
+	 * @param string $value		設定値
+	 * @return なし
+	 */
+	public static function setRefer($value)
+	{
+		self::$refer = $value;
+	}
 	/**
 	 * 編集元データ値を取得
 	 *
@@ -224,15 +243,6 @@ class WikiParam
 	{
 		self::$digest = $value;
 	}
-	/**
-	 * レファラー値を取得
-	 *
-	 * @return string	レファラー値
-	 */
-	public static function getRefer()
-	{
-		return self::$refer;
-	}
 	/**
 	 * 全パラメータを取得
 	 *
