@@ -1,14 +1,24 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone
-// $Id: attach.inc.php 1032 2008-09-22 06:47:54Z fishbone $
+/**
+ * attachプラグイン
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: attach.inc.php 1083 2008-10-17 15:35:10Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2003-2006 PukiWiki Developers Team
 //   2002-2003 PANDA <panda@arino.jp> http://home.arino.jp/
 //   2002      Y.MASUI <masui@hisec.co.jp> http://masui.net/pukiwiki/
 //   2001-2002 Originally written by yu-ji
 // License: GPL v2 or (at your option) any later version
-//
-// File attach plugin
 
 // NOTE (PHP > 4.2.3):
 //    This feature is disabled at newer version of PHP.
@@ -50,9 +60,10 @@ define('PLUGIN_ATTACH_CONFIG_PAGE_MIME', 'plugin/attach/mime-type');
 //-------- convert
 function plugin_attach_convert()
 {
-	global $vars;
+//	global $vars;
 
-	$page = isset($vars['page']) ? $vars['page'] : '';
+	//$page = isset($vars['page']) ? $vars['page'] : '';
+	$page = WikiParam::getPage();
 
 	$nolist = $noform = FALSE;
 	if (func_num_args() > 0) {
@@ -65,35 +76,40 @@ function plugin_attach_convert()
 
 	$ret = '';
 	if (! $nolist) {
-		$obj  = & new AttachPages($page);
+		$obj  = new AttachPages($page);
 		$ret .= $obj->toString($page, TRUE);
 	}
 	if (! $noform) {
 		$ret .= attach_form($page);
 	}
-
 	return $ret;
 }
 
 //-------- action
 function plugin_attach_action()
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
 	// Backward compatible
-	if (isset($vars['openfile'])) {
+	/*if (isset($vars['openfile'])) {
 		$vars['file'] = $vars['openfile'];
 		$vars['pcmd'] = 'open';
 	}
 	if (isset($vars['delfile'])) {
 		$vars['file'] = $vars['delfile'];
 		$vars['pcmd'] = 'delete';
-	}
+	}*/
 
-	$pcmd  = isset($vars['pcmd'])  ? $vars['pcmd']  : '';
+	/*$pcmd  = isset($vars['pcmd'])  ? $vars['pcmd']  : '';
 	$refer = isset($vars['refer']) ? $vars['refer'] : '';
 	$pass  = isset($vars['pass'])  ? $vars['pass']  : NULL;
-	$page  = isset($vars['page'])  ? $vars['page']  : '';
+	$page  = isset($vars['page'])  ? $vars['page']  : '';*/
+	
+	$pcmd = WikiParam::getVar('pcmd');
+	$refer = WikiParam::getRefer();
+	$pass = WikiParam::getVar('pass');
+	$page = WikiParam::getPage();
 
 	if ($refer != '' && is_pagename($refer)) {
 		if(in_array($pcmd, array('info', 'open', 'list'))) {
@@ -135,11 +151,13 @@ function plugin_attach_action()
 //-------- call from skin
 function attach_filelist()
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
-	$page = isset($vars['page']) ? $vars['page'] : '';
+	//$page = isset($vars['page']) ? $vars['page'] : '';
+	$page = WikiParam::getPage();
 
-	$obj = & new AttachPages($page, 0);
+	$obj = new AttachPages($page, 0);
 
 	if (! isset($obj->pages[$page])) {
 		return '';
@@ -186,7 +204,7 @@ function attach_upload($file, $page, $pass = NULL)
 			'msg'=>$_attach_messages['err_adminpass']);
 	}
 
-	$obj = & new AttachFile($page, $file['name']);
+	$obj = new AttachFile($page, $file['name']);
 	if ($obj->exist)
 		return array('result'=>FALSE,
 			'msg'=>$_attach_messages['err_exists']);
@@ -231,12 +249,18 @@ function attach_upload($file, $page, $pass = NULL)
 // 詳細フォームを表示
 function attach_info($err = '')
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
-	foreach (array('refer', 'file', 'age') as $var)
-		${$var} = isset($vars[$var]) ? $vars[$var] : '';
+	//foreach (array('refer', 'file', 'age') as $var)
+	//	${$var} = isset($vars[$var]) ? $vars[$var] : '';
 
-	$obj = & new AttachFile($refer, $file, $age);
+	//$obj = new AttachFile($refer, $file, $age);
+	$refer = WikiParam::getRefer();
+	$file = WikiParam::getVar('file');
+	$age = WikiParam::getVar('age');
+	
+	$obj = new AttachFile($refer, $file, $age);
 	return $obj->getstatus() ?
 		$obj->info($err) :
 		array('msg'=>$_attach_messages['err_notfound']);
@@ -245,15 +269,20 @@ function attach_info($err = '')
 // 削除
 function attach_delete()
 {
-	global $vars, $_attach_messages;
-
-	foreach (array('refer', 'file', 'age', 'pass') as $var)
-		${$var} = isset($vars[$var]) ? $vars[$var] : '';
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
+	//foreach (array('refer', 'file', 'age', 'pass') as $var)
+	//	${$var} = isset($vars[$var]) ? $vars[$var] : '';
+	$refer = WikiParam::getRefer();
+	$file = WikiParam::getVar('file');
+	$age = WikiParam::getVar('age');
+	$pass = WikiParam::getVar('pass');
+	
 	if (is_freeze($refer) || ! is_editable($refer))
 		return array('msg'=>$_attach_messages['err_noparm']);
 
-	$obj = & new AttachFile($refer, $file, $age);
+	$obj = new AttachFile($refer, $file, $age);
 	if (! $obj->getstatus())
 		return array('msg'=>$_attach_messages['err_notfound']);
 		
@@ -263,16 +292,21 @@ function attach_delete()
 // 凍結
 function attach_freeze($freeze)
 {
-	global $vars, $_attach_messages;
-
-	foreach (array('refer', 'file', 'age', 'pass') as $var) {
-		${$var} = isset($vars[$var]) ? $vars[$var] : '';
-	}
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
+	//foreach (array('refer', 'file', 'age', 'pass') as $var) {
+	//	${$var} = isset($vars[$var]) ? $vars[$var] : '';
+	//}
+	$refer = WikiParam::getRefer();
+	$file = WikiParam::getVar('file');
+	$age = WikiParam::getVar('age');
+	$pass = WikiParam::getVar('pass');
+	
 	if (is_freeze($refer) || ! is_editable($refer)) {
 		return array('msg'=>$_attach_messages['err_noparm']);
 	} else {
-		$obj = & new AttachFile($refer, $file, $age);
+		$obj = new AttachFile($refer, $file, $age);
 		return $obj->getstatus() ?
 			$obj->freeze($freeze, $pass) :
 			array('msg'=>$_attach_messages['err_notfound']);
@@ -282,16 +316,22 @@ function attach_freeze($freeze)
 // リネーム
 function attach_rename()
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
-	foreach (array('refer', 'file', 'age', 'pass', 'newname') as $var) {
+	/*foreach (array('refer', 'file', 'age', 'pass', 'newname') as $var) {
 		${$var} = isset($vars[$var]) ? $vars[$var] : '';
-	}
-
+	}*/
+	$refer = WikiParam::getRefer();
+	$file = WikiParam::getVar('file');
+	$age = WikiParam::getVar('age');
+	$pass = WikiParam::getVar('pass');
+	$newname = WikiParam::getVar('newname');
+	
 	if (is_freeze($refer) || ! is_editable($refer)) {
 		return array('msg'=>$_attach_messages['err_noparm']);
 	}
-	$obj = & new AttachFile($refer, $file, $age);
+	$obj = new AttachFile($refer, $file, $age);
 	if (! $obj->getstatus())
 		return array('msg'=>$_attach_messages['err_notfound']);
 
@@ -302,13 +342,17 @@ function attach_rename()
 // ダウンロード
 function attach_open()
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
-	foreach (array('refer', 'file', 'age') as $var) {
+	/*foreach (array('refer', 'file', 'age') as $var) {
 		${$var} = isset($vars[$var]) ? $vars[$var] : '';
-	}
+	}*/
+	$refer = WikiParam::getRefer();
+	$file = WikiParam::getVar('file');
+	$age = WikiParam::getVar('age');
 
-	$obj = & new AttachFile($refer, $file, $age);
+	$obj = new AttachFile($refer, $file, $age);
 	return $obj->getstatus() ?
 		$obj->open() :
 		array('msg'=>$_attach_messages['err_notfound']);
@@ -317,11 +361,13 @@ function attach_open()
 // 一覧取得
 function attach_list()
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
-	$refer = isset($vars['refer']) ? $vars['refer'] : '';
+	//$refer = isset($vars['refer']) ? $vars['refer'] : '';
+	$refer = WikiParam::getRefer();
 
-	$obj = & new AttachPages($refer);
+	$obj = new AttachPages($refer);
 
 	$msg = $_attach_messages[($refer == '') ? 'msg_listall' : 'msg_listpage'];
 	$body = ($refer == '' || isset($obj->pages[$refer])) ?
@@ -334,12 +380,16 @@ function attach_list()
 // アップロードフォームを表示 (action時)
 function attach_showform()
 {
-	global $vars, $_attach_messages;
+	//global $vars, $_attach_messages;
+	global $_attach_messages;
 
-	$page = isset($vars['page']) ? $vars['page'] : '';
-	$vars['refer'] = $page;
+	/*$page = isset($vars['page']) ? $vars['page'] : '';
+	$vars['refer'] = $page;*/
+	
+	$page = WikiParam::getPage();
+	WikiParam::setRefer($page);
 	$body = attach_form($page);
-
+	
 	return array('msg'=>$_attach_messages['msg_upload'], 'body'=>$body);
 }
 
@@ -386,7 +436,8 @@ function attach_mime_content_type($filename)
 // アップロードフォームの出力
 function attach_form($page)
 {
-	global $script, $vars, $_attach_messages;
+	//global $script, $vars, $_attach_messages;
+	global $script, $_attach_messages;
 
 	$r_page = rawurlencode($page);
 	$s_page = htmlspecialchars($page);
@@ -408,8 +459,9 @@ EOD;
 		$title = $_attach_messages[PLUGIN_ATTACH_UPLOAD_ADMIN_ONLY ? 'msg_adminpass' : 'msg_password'];
 		$pass = '<br />' . $title . ': <input type="password" name="pass" size="8" />';
 	}
-	return <<<EOD
-<form enctype="multipart/form-data" action="$script" method="post">
+	$postScript = $script . WikiParam::convQuery("?");
+	$retValue = <<<EOD
+<form enctype="multipart/form-data" action="$postScript" method="post">
  <div>
   <input type="hidden" name="plugin" value="attach" />
   <input type="hidden" name="pcmd"   value="post" />
@@ -425,6 +477,24 @@ EOD;
  </div>
 </form>
 EOD;
+	return $retValue;
+	/*return <<<EOD
+<form enctype="multipart/form-data" action="$script" method="post">
+ <div>
+  <input type="hidden" name="plugin" value="attach" />
+  <input type="hidden" name="pcmd"   value="post" />
+  <input type="hidden" name="refer"  value="$s_page" />
+  <input type="hidden" name="max_file_size" value="$maxsize" />
+  $navi
+  <span class="small">
+   $msg_maxsize
+  </span><br />
+  <label for="_p_attach_file">{$_attach_messages['msg_file']}:</label> <input type="file" name="attach_file" id="_p_attach_file" />
+  $pass
+  <input type="submit" value="{$_attach_messages['btn_upload']}" />
+ </div>
+</form>
+EOD;*/
 }
 
 //-------- クラス
@@ -739,7 +809,7 @@ class AttachFiles
 
 	function add($file, $age)
 	{
-		$this->files[$file][$age] = & new AttachFile($this->page, $file, $age);
+		$this->files[$file][$age] = new AttachFile($this->page, $file, $age);
 	}
 
 	// ファイル一覧を取得
@@ -821,7 +891,7 @@ class AttachPages
 			$_file = decode($matches[2]);
 			$_age  = isset($matches[3]) ? $matches[3] : 0;
 			if (! isset($this->pages[$_page])) {
-				$this->pages[$_page] = & new AttachFiles($_page);
+				$this->pages[$_page] = new AttachFiles($_page);
 			}
 			$this->pages[$_page]->add($_file, $_age);
 		}
