@@ -1,19 +1,30 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: backup.inc.php 1032 2008-09-22 06:47:54Z fishbone $
+/**
+ * backupプラグイン
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: backup.inc.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2002-2005 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
 // License: GPL v2 or (at your option) any later version
-//
-// Backup plugin
 
 // Prohibit rendering old wiki texts (suppresses load, transfer rate, and security risk)
 define('PLUGIN_BACKUP_DISABLE_BACKUP_RENDERING', PKWK_SAFE_MODE || PKWK_OPTIMISE);
 
 function plugin_backup_action()
 {
-	global $vars, $do_backup, $hr;
+	//global $vars, $do_backup, $hr;
+	global $do_backup, $hr;
 	global $_msg_backuplist, $_msg_diff, $_msg_nowdiff, $_msg_source, $_msg_backup;
 	global $_msg_view, $_msg_goto, $_msg_deleted;
 	global $_title_backupdiff, $_title_backupnowdiff, $_title_backupsource;
@@ -21,14 +32,16 @@ function plugin_backup_action()
 
 	if (! $do_backup) return;
 
-	$page = isset($vars['page']) ? $vars['page']  : '';
+	//$page = isset($vars['page']) ? $vars['page']  : '';
+	$page = WikiParam::getPage();
 	if ($page == '') return array('msg'=>$_title_backuplist, 'body'=>plugin_backup_get_list_all());
 
 	check_readable($page, true, true);
 	$s_page = htmlspecialchars($page);
 	$r_page = rawurlencode($page);
 
-	$action = isset($vars['action']) ? $vars['action'] : '';
+	//$action = isset($vars['action']) ? $vars['action'] : '';
+	$action = WikiParam::getVar('action');
 	if ($action == 'delete') return plugin_backup_delete($page);
 
 	$s_action = $r_action = '';
@@ -37,15 +50,19 @@ function plugin_backup_action()
 		$r_action = rawurlencode($action);
 	}
 
-	$s_age  = (isset($vars['age']) && is_numeric($vars['age'])) ? $vars['age'] : 0;
+	//$s_age  = (isset($vars['age']) && is_numeric($vars['age'])) ? $vars['age'] : 0;
+	$value = WikiParam::getVar('age');
+	$s_age  = ($value == '') ? 0 : intval($value);
 	if ($s_age <= 0) return array( 'msg'=>$_title_pagebackuplist, 'body'=>plugin_backup_get_list($page));
 
 	$script = get_script_uri();
 
 	$body  = '<ul>' . "\n";
-	$body .= ' <li><a href="' . $script . '?cmd=backup">' . $_msg_backuplist . '</a></li>' ."\n";
+	//$body .= ' <li><a href="' . $script . '?cmd=backup">' . $_msg_backuplist . '</a></li>' ."\n";
+	$body .= ' <li><a href="' . $script . WikiParam::convQuery('?cmd=backup') . '">' . $_msg_backuplist . '</a></li>' ."\n";
 
-	$href    = $script . '?cmd=backup&amp;page=' . $r_page . '&amp;age=' . $s_age;
+	//$href    = $script . '?cmd=backup&amp;page=' . $r_page . '&amp;age=' . $s_age;
+	$href    = $script . WikiParam::convQuery('?cmd=backup&amp;page=' . $r_page . '&amp;age=' . $s_age);
 	$is_page = is_page($page);
 
 	if ($is_page && $action != 'diff')
@@ -84,11 +101,12 @@ function plugin_backup_action()
 		$body .= '  <ul>' . "\n";
 		foreach($backups as $age => $val) {
 			$date = format_date($val['time'], TRUE);
+			/*$body .= ($age == $s_age) ?
+				'   <li><em>' . $age . ' ' . $date . '</em></li>' . "\n" :
+				'   <li><a href="' . $script . '?cmd=backup&amp;action=' . $r_action . '&amp;page=' . $r_page . '&amp;age=' . $age . '">' . $age . ' ' . $date . '</a></li>' . "\n";*/
 			$body .= ($age == $s_age) ?
 				'   <li><em>' . $age . ' ' . $date . '</em></li>' . "\n" :
-				'   <li><a href="' . $script . '?cmd=backup&amp;action=' .
-				$r_action . '&amp;page=' . $r_page . '&amp;age=' . $age .
-				'">' . $age . ' ' . $date . '</a></li>' . "\n";
+				'   <li><a href="' . $script . WikiParam::convQuery('?cmd=backup&amp;action=' . $r_action . '&amp;page=' . $r_page . '&amp;age=' . $age) . '">' . $age . ' ' . $date . '</a></li>' . "\n";
 		}
 		$body .= '  </ul>' . "\n";
 	}
@@ -125,14 +143,16 @@ function plugin_backup_action()
 // Delete backup
 function plugin_backup_delete($page)
 {
-	global $vars, $_title_backup_delete, $_title_pagebackuplist, $_msg_backup_deleted;
+	//global $vars, $_title_backup_delete, $_title_pagebackuplist, $_msg_backup_deleted;
+	global $_title_backup_delete, $_title_pagebackuplist, $_msg_backup_deleted;
 	global $_msg_backup_adminpass, $_btn_delete, $_msg_invalidpass;
 
 	if (! _backup_file_exists($page))
 		return array('msg'=>$_title_pagebackuplist, 'body'=>plugin_backup_get_list($page)); // Say "is not found"
 
 	$body = '';
-	if (isset($vars['pass'])) {
+	$pass = WikiParam::getVar('pass');
+	/*if (isset($vars['pass'])) {
 		if (pkwk_login($vars['pass'])) {
 			_backup_delete($page);
 			return array(
@@ -142,9 +162,20 @@ function plugin_backup_delete($page)
 		} else {
 			$body = '<p><strong>' . $_msg_invalidpass . '</strong></p>' . "\n";
 		}
+	}*/
+	if ($pass != ''){
+		if (pkwk_login($pass)){
+			_backup_delete($page);
+			return array(
+				'msg'  => $_title_backup_delete,
+				'body' => str_replace('$1', make_pagelink($page), $_msg_backup_deleted)
+			);
+		} else {
+			$body = '<p><strong>' . $_msg_invalidpass . '</strong></p>' . "\n";
+		}
 	}
 
-	$script = get_script_uri();
+/*	$script = get_script_uri();
 	$s_page = htmlspecialchars($page);
 	$body .= <<<EOD
 <p>$_msg_backup_adminpass</p>
@@ -157,6 +188,21 @@ function plugin_backup_delete($page)
   <input type="submit"   name="ok"     value="$_btn_delete" />
  </div>
 </form>
+EOD;*/
+	$postScript = get_script_uri() . WikiParam::convQuery("?");
+	$s_page = htmlspecialchars($page);
+	$body .= <<<EOD
+<p>$_msg_backup_adminpass</p>
+<form action="$postScript" method="post">
+ <div>
+  <input type="hidden"   name="wcmd"    value="backup" />
+  <input type="hidden"   name="page"   value="$s_page" />
+  <input type="hidden"   name="action" value="delete" />
+  <input type="hidden"   name="pass" />
+  <input type="password" name="password" size="12" />
+  <input type="submit"   name="ok"     value="$_btn_delete" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+ </div>
+</form>
 EOD;
 	return	array('msg'=>$_title_backup_delete, 'body'=>$body);
 }
@@ -181,10 +227,11 @@ function plugin_backup_get_list($page)
 	global $_title_backup_delete;
 
 	$script = get_script_uri();
+	$postScript = $script . WikiParam::convQuery('?cmd=backup');
 	$r_page = rawurlencode($page);
 	$s_page = htmlspecialchars($page);
 	$retval = array();
-	$retval[0] = <<<EOD
+/*	$retval[0] = <<<EOD
 <ul>
  <li><a href="$script?cmd=backup">$_msg_backuplist</a>
   <ul>
@@ -194,8 +241,18 @@ EOD;
   </ul>
  </li>
 </ul>
+EOD;*/
+	$retval[0] = <<<EOD
+<ul>
+ <li><a href="$postScript">$_msg_backuplist</a>
+  <ul>
+EOD;
+	$retval[1] = "\n";
+	$retval[2] = <<<EOD
+  </ul>
+ </li>
+</ul>
 EOD;
-
 	$backups = _backup_file_exists($page) ? get_backup($page) : array();
 	if (empty($backups)) {
 		$msg = str_replace('$1', make_pagelink($page), $_msg_nobackup);
@@ -204,27 +261,38 @@ EOD;
 	}
 
 	if (! PKWK_READONLY) {
-		$retval[1] .= '   <li><a href="' . $script . '?cmd=backup&amp;action=delete&amp;page=' .
-			$r_page . '">';
+		//$retval[1] .= '   <li><a href="' . $script . '?cmd=backup&amp;action=delete&amp;page=' . $r_page . '">';
+		$retval[1] .= '   <li><a href="' . $script . WikiParam::convQuery('?cmd=backup&amp;action=delete&amp;page=' . $r_page) . '">';
 		$retval[1] .= str_replace('$1', $s_page, $_title_backup_delete);
 		$retval[1] .= '</a></li>' . "\n";
 	}
 
-	$href = $script . '?cmd=backup&amp;page=' . $r_page . '&amp;age=';
+	//$href = $script . '?cmd=backup&amp;page=' . $r_page . '&amp;age=';
+	$query = '?cmd=backup&amp;page=' . $r_page . '&amp;age=';
 	$_anchor_from = $_anchor_to   = '';
 	foreach ($backups as $age=>$data) {
 		if (! PLUGIN_BACKUP_DISABLE_BACKUP_RENDERING) {
-			$_anchor_from = '<a href="' . $href . $age . '">';
+			//$_anchor_from = '<a href="' . $href . $age . '">';
+			$_anchor_from = '<a href="' . $script . WikiParam::convQuery($query . $age) . '">';
 			$_anchor_to   = '</a>';
 		}
 		$date = format_date($data['time'], TRUE);
-		$retval[1] .= <<<EOD
+		/*$retval[1] .= <<<EOD
    <li>$_anchor_from$age $date$_anchor_to
      [ <a href="$href$age&amp;action=diff">$_msg_diff</a>
      | <a href="$href$age&amp;action=nowdiff">$_msg_nowdiff</a>
      | <a href="$href$age&amp;action=source">$_msg_source</a>
      ]
    </li>
+EOD;*/
+		$url = $script . WikiParam::convQuery($query . $age);
+		$retval[1] .= <<<EOD
+   <li>$_anchor_from$age $date$_anchor_to
+     [ <a href="$url&amp;action=diff">$_msg_diff</a>
+     | <a href="$url&amp;action=nowdiff">$_msg_nowdiff</a>
+     | <a href="$url&amp;action=source">$_msg_source</a>
+     ]
+   </li>
 EOD;
 	}
 
