@@ -1,12 +1,23 @@
 <?php
+/**
+ * editプラグイン
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: edit.inc.php 1084 2008-10-18 06:10:55Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: edit.inc.php 1068 2008-10-10 11:46:46Z fishbone $
+// $Id: edit.inc.php 1084 2008-10-18 06:10:55Z fishbone $
 // Copyright (C) 2001-2006 PukiWiki Developers Team
 // License: GPL v2 or (at your option) any later version
-//
-// Edit plugin (cmd=edit)
 
-// Remove #freeze written by hand
 define('PLUGIN_EDIT_FREEZE_REGEX', '/^(?:#freeze(?!\w)\s*)+/im');
 
 function plugin_edit_action()
@@ -26,7 +37,8 @@ function plugin_edit_action()
 	if (!check_editable($page, true, true)){		// 編集不可のとき
 		//$body = $title = str_replace('$1',
 			//htmlspecialchars(strip_bracket($page)), $_title_cannotedit);
-		$body = $title = str_replace('$1', make_search($page), $_title_cannotedit);
+		//$body = $title = str_replace('$1', make_search($page), $_title_cannotedit);
+		$body = $title = str_replace('$1', make_pagelink($page), $_title_cannotedit);
 		if (is_freeze($page)){
 			$body .= '(<a href="' . $script . WikiParam::convQuery('?cmd=unfreeze&amp;page=' . rawurlencode($page)) . '">' . $_msg_unfreeze . '</a>)';
 		}
@@ -306,7 +318,7 @@ function plugin_edit_write()
 // Cancel (Back to the page / Escape edit page)
 function plugin_edit_cancel()
 {
-	global $vars;
+	//global $vars;
 	pkwk_headers_sent();
 	// modified for Magic3 by naoki on 2008/10/6
 	//header('Location: ' . get_script_uri() . '?' . rawurlencode($vars['page']));
