@@ -1,9 +1,18 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone
-// $Id: tracker.inc.php 1063 2008-10-08 10:36:47Z fishbone $
-//
-// Issue tracker plugin (See Also bugtrack plugin)
-
+/**
+ * trackerプラグイン
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: tracker.inc.php 1083 2008-10-17 15:35:10Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // tracker_listで表示しないページ名(正規表現で)
 // 'SubMenu'ページ および '/'を含むページを除外する
 define('TRACKER_LIST_EXCLUDE_PATTERN','#^SubMenu$|/#');
@@ -175,7 +184,7 @@ function plugin_tracker_action()
 	$r_page = rawurlencode($page);
 
 	pkwk_headers_sent();
-	header('Location: ' . get_script_uri() . '?' . $r_page);
+	header('Location: ' . get_script_uri() . WikiParam::convQuery('?' . $r_page, false));
 	exit;
 }
 /*
